Analysing Pulsar Data
*********************

The subpackage ``stingray.pulse`` implements a set of tools for 
analysing (X-ray) pulsar data, in particular periodicity searches.

Below, we show examples of how this functionality can be implemented and 
used in practice.

.. toctree::
   :maxdepth: 2

   notebooks/Pulsar/Pulsar search with epoch folding and Z squared.ipynb
